==> bluedevil-1.0.6.tar.bz2: bluedevil-1.0.6/src/daemon/helpers/filereceiver/service.h <==
/***************************************************************************
 *   Copyright (C) 2010 Eduardo Robles Elvira <edulix@gmail.com>           *
 *   Copyright (C) 2010 Alejandro Fiestas Olivares <alex@eyeos.org>        *
 *   Copyright (C) 2010 UFO Coders <info@ufocoders.com>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef SERVICE_H
#define SERVICE_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>

#include "openobex/server.h"
class QDBusServiceWatcher;
class Service
    : public QObject
{
    Q_OBJECT

public:
    Service();
    virtual ~Service();

public Q_SLOTS:
    void launchServer();
    void stopServer();
    bool isRunning();

private Q_SLOTS:
    void openobexUnregistered();

private:
    OpenObex::Server* m_server;
    QDBusServiceWatcher *m_watcher;
};

#endif // SERVICE_H

==> bluedevil_1.1.orig.tar.bz2: bluedevil-1.1/src/daemon/helpers/filereceiver/service.h <==
/***************************************************************************
 *   Copyright (C) 2010 Eduardo Robles Elvira <edulix@gmail.com>           *
 *   Copyright (C) 2010 Alejandro Fiestas Olivares <alex@eyeos.org>        *
 *   Copyright (C) 2010 UFO Coders <info@ufocoders.com>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef SERVICE_H
#define SERVICE_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>

#include "openobex/server.h"
#include "openobex/serverftp.h"

class QDBusServiceWatcher;
class Service
    : public QObject
{
    Q_OBJECT

public:
    Service();
    virtual ~Service();

public Q_SLOTS:
    void launchServer();
    void stopServer();
    bool isRunning();

private Q_SLOTS:
    void openobexUnregistered();

private:
    OpenObex::Server *m_server;
    OpenObex::ServerFtp *m_serverftp;
    QDBusServiceWatcher *m_watcher;
};

#endif // SERVICE_H
